{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap-deseq:v0.0.18"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-o"
                    },
                    "doc": "Output prefix. Default: deseq\n",
                    "id": "#deseq-advanced.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "-cu"
                    },
                    "doc": "Minimum threshold for rpkm filtering. Default: 5\n",
                    "id": "#deseq-advanced.cwl/rpkm_cutoff"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "-p"
                    },
                    "doc": "Run script using multiple threads\n",
                    "id": "#deseq-advanced.cwl/threads"
                },
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-t"
                    },
                    "doc": "Treated input CSV/TSV files\n",
                    "id": "#deseq-advanced.cwl/treated_files"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-tn"
                    },
                    "doc": "Name for treated condition, use only letters and numbers\n",
                    "id": "#deseq-advanced.cwl/treated_name"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-ta"
                    },
                    "doc": "Unique aliases for treated expression files. Default: basenames of -t without extensions\n",
                    "id": "#deseq-advanced.cwl/treated_sample_names"
                },
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-u"
                    },
                    "doc": "Untreated input CSV/TSV files\n",
                    "id": "#deseq-advanced.cwl/untreated_files"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-un"
                    },
                    "doc": "Name for untreated condition, use only letters and numbers\n",
                    "id": "#deseq-advanced.cwl/untreated_name"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-ua"
                    },
                    "doc": "Unique aliases for untreated expression files. Default: basenames of -u without extensions\n",
                    "id": "#deseq-advanced.cwl/untreated_sample_names"
                }
            ],
            "baseCommand": [
                "run_deseq.R"
            ],
            "stdout": "deseq_stdout.log",
            "stderr": "deseq_stderr.log",
            "doc": "Tool runs DESeq/DESeq2 script similar to the original one from BioWArdrobe.\nuntreated_files and treated_files input files should have the following header (case-sensitive)\n<RefseqId,GeneId,Chrom,TxStart,TxEnd,Strand,TotalReads,Rpkm>         - CSV\n<RefseqId\\tGeneId\\tChrom\\tTxStart\\tTxEnd\\tStrand\\tTotalReads\\tRpkm>  - TSV\n\nFormat of the input files is identified based on file's extension\n*.csv - CSV\n*.tsv - TSV\nOtherwise used CSV by default\n\nThe output file's rows order corresponds to the rows order of the first CSV/TSV file in\nthe untreated group. Output is always saved in TSV format\n\nOutput file includes only intersected rows from all input files. Intersected by\nRefseqId, GeneId, Chrom, TxStart, TxEnd, Strand\n\nDESeq/DESeq2 always compares untreated_vs_treated groups.\nNormalized read counts and phenotype table are exported as GCT and CLS files for GSEA downstream analysis.\n",
            "id": "#deseq-advanced.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#deseq-metadata.yaml",
                "http://schema.org/name": "DESeq",
                "http://schema.org/about": "Differential expression of RNA-Seq data at the gene level"
            },
            "http://schema.org/name": "deseq-advanced",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/deseq-advanced.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage: run_deseq.R\n      [-h] -u UNTREATED [UNTREATED ...] -t TREATED [TREATED ...]\n      [-ua [UALIAS [UALIAS ...]]] [-ta [TALIAS [TALIAS ...]]] [-un UNAME]\n      [-tn TNAME] [-o OUTPUT] [-p THREADS]\n\nRun BioWardrobe DESeq/DESeq2 for untreated-vs-treated groups\n\noptional arguments:\n  -h, --help            show this help message and exit\n  -u UNTREATED [UNTREATED ...], --untreated UNTREATED [UNTREATED ...]\n                        Untreated CSV/TSV isoforms expression files\n  -t TREATED [TREATED ...], --treated TREATED [TREATED ...]\n                        Treated CSV/TSV isoforms expression files\n  -ua [UALIAS [UALIAS ...]], --ualias [UALIAS [UALIAS ...]]\n                        Unique aliases for untreated expression files.\n                        Default: basenames of -u without extensions\n  -ta [TALIAS [TALIAS ...]], --talias [TALIAS [TALIAS ...]]\n                        Unique aliases for treated expression files. Default:\n                        basenames of -t without extensions\n  -un UNAME, --uname UNAME\n                        Name for untreated condition, use only letters and\n                        numbers\n  -tn TNAME, --tname TNAME\n                        Name for treated condition, use only letters and\n                        numbers\n  -o OUTPUT, --output OUTPUT\n                        Output prefix. Default: deseq\n  -p THREADS, --threads THREADS\n                        Threads\n",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*report.tsv"
                    },
                    "id": "#deseq-advanced.cwl/diff_expr_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_expression_heatmap.png"
                    },
                    "id": "#deseq-advanced.cwl/gene_expr_heatmap"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_expression_heatmap.pdf"
                    },
                    "id": "#deseq-advanced.cwl/gene_expr_heatmap_pdf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*phenotypes.cls"
                    },
                    "id": "#deseq-advanced.cwl/phenotypes_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_ma_plot.png"
                    },
                    "id": "#deseq-advanced.cwl/plot_lfc_vs_mean"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_ma_plot.pdf"
                    },
                    "id": "#deseq-advanced.cwl/plot_lfc_vs_mean_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_pca_plot.png"
                    },
                    "id": "#deseq-advanced.cwl/plot_pca"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_pca_plot.pdf"
                    },
                    "id": "#deseq-advanced.cwl/plot_pca_pdf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*counts.gct"
                    },
                    "id": "#deseq-advanced.cwl/read_counts_file"
                },
                {
                    "type": "File",
                    "id": "#deseq-advanced.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "deseq_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#deseq-advanced.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "deseq_stdout.log"
                    }
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Isoforms CSV file(s)",
                    "id": "#group-isoforms-batch.cwl/isoforms_file"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#group-isoforms-batch.cwl/group_isoforms/common_tss_file",
                    "doc": "Common tss expression file(s) in TSV format",
                    "id": "#group-isoforms-batch.cwl/common_tss_file"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#group-isoforms-batch.cwl/group_isoforms/genes_file",
                    "doc": "Gene expression file(s) in TSV format",
                    "id": "#group-isoforms-batch.cwl/genes_file"
                }
            ],
            "steps": [
                {
                    "run": "#group-isoforms.cwl",
                    "in": [
                        {
                            "source": "#group-isoforms-batch.cwl/isoforms_file",
                            "id": "#group-isoforms-batch.cwl/group_isoforms/isoforms_file"
                        }
                    ],
                    "scatter": [
                        "#group-isoforms-batch.cwl/group_isoforms/isoforms_file"
                    ],
                    "out": [
                        "#group-isoforms-batch.cwl/group_isoforms/genes_file",
                        "#group-isoforms-batch.cwl/group_isoforms/common_tss_file"
                    ],
                    "id": "#group-isoforms-batch.cwl/group_isoforms"
                }
            ],
            "doc": "Workflow runs group-isoforms.cwl tool using scatter for isoforms_file input. genes_filename and common_tss_filename inputs are ignored.\n",
            "id": "#group-isoforms-batch.cwl",
            "http://schema.org/name": "group-isoforms-batch",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Workflow runs group-isoforms.cwl tool using scatter for isoforms_file input. genes_filename and common_tss_filename inputs are ignored."
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap-deseq:v0.0.18"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--tss"
                    },
                    "doc": "Output TSV common tss expression filename",
                    "id": "#group-isoforms.cwl/common_tss_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--gene"
                    },
                    "doc": "Output TSV gene expression filename",
                    "id": "#group-isoforms.cwl/genes_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--isoforms"
                    },
                    "doc": "Isoforms CSV file",
                    "id": "#group-isoforms.cwl/isoforms_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.common_tss_file?inputs.common_tss_file:\"*common_tss.tsv\")"
                    },
                    "doc": "Output TSV common tss expression file",
                    "id": "#group-isoforms.cwl/common_tss_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.genes_filename?inputs.genes_filename:\"*genes.tsv\")"
                    },
                    "doc": "Output TSV gene expression file",
                    "id": "#group-isoforms.cwl/genes_file"
                }
            ],
            "baseCommand": [
                "get_gene_n_tss.R"
            ],
            "doc": "Tool runs get_gene_n_tss.R script to group isoforms by gene and common TSS\n",
            "id": "#group-isoforms.cwl",
            "http://schema.org/mainEntity": {
                "$import": "#deseq-metadata.yaml"
            },
            "http://schema.org/name": "group-isoforms",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/group-isoforms.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage: get_gene_n_tss.R [-h] --isoforms ISOFORMS [--gene GENE] [--tss TSS]\n\nGroup isoform expression data by gene and common TSS\n\noptional arguments:\n  -h, --help           show this help message and exit\n  --isoforms ISOFORMS  Input CSV isoform expression file\n  --gene GENE          Output TSV gene expression file\n  --tss TSS            Output TSV common tss expression file"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "sd:upstream": {
                "rnaseq_cond_1": [
                    "rnaseq-se.cwl",
                    "rnaseq-pe.cwl",
                    "rnaseq-se-dutp.cwl",
                    "rnaseq-pe-dutp.cwl",
                    "rnaseq-se-dutp-mitochondrial.cwl",
                    "rnaseq-pe-dutp-mitochondrial.cwl",
                    "trim-rnaseq-pe.cwl",
                    "trim-rnaseq-se.cwl",
                    "trim-rnaseq-pe-dutp.cwl",
                    "trim-rnaseq-se-dutp.cwl"
                ],
                "rnaseq_cond_2": [
                    "rnaseq-se.cwl",
                    "rnaseq-pe.cwl",
                    "rnaseq-se-dutp.cwl",
                    "rnaseq-pe-dutp.cwl",
                    "rnaseq-se-dutp-mitochondrial.cwl",
                    "rnaseq-pe-dutp-mitochondrial.cwl",
                    "trim-rnaseq-pe.cwl",
                    "trim-rnaseq-se.cwl",
                    "trim-rnaseq-pe-dutp.cwl",
                    "trim-rnaseq-se-dutp.cwl"
                ]
            },
            "inputs": [
                {
                    "type": "string",
                    "label": "Experiment short name/Alias",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/alias"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "untreated",
                    "label": "Alias for condition 1, aka 'untreated' (letters and numbers only)",
                    "doc": "Name to be displayed for condition 1, aka 'untreated' (letters and numbers only)",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/alias_cond_1"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "treated",
                    "label": "Alias for condition 2, aka 'treated' (letters and numbers only)",
                    "doc": "Name to be displayed for condition 2, aka 'treated' (letters and numbers only)",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/alias_cond_2"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/group_by/isoforms",
                                "#main/group_by/genes",
                                "#main/group_by/common tss"
                            ]
                        }
                    ],
                    "default": "genes",
                    "label": "Group by",
                    "doc": "Grouping method for features: isoforms, genes or common tss",
                    "id": "#main/group_by"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 5,
                    "label": "Minimum rpkm cutoff",
                    "doc": "Minimum threshold for rpkm filtering. Default: 5",
                    "id": "#main/rpkm_cutoff"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_3752",
                    "label": "RNA-Seq experiments (condition 1, aka 'untreated')",
                    "doc": "CSV/TSV input files grouped by isoforms (condition 1, aka 'untreated')",
                    "sd:upstreamSource": "rnaseq_cond_1/rpkm_isoforms",
                    "sd:localLabel": true,
                    "id": "#main/rpkm_isoforms_cond_1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_3752",
                    "label": "RNA-Seq experiments (condition 2, aka 'treated')",
                    "doc": "CSV/TSV input files grouped by isoforms (condition 2, aka 'treated')",
                    "sd:upstreamSource": "rnaseq_cond_2/rpkm_isoforms",
                    "sd:localLabel": true,
                    "id": "#main/rpkm_isoforms_cond_2"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "label": "Sample names for RNA-Seq experiments (condition 1, aka 'untreated')",
                    "doc": "Aliases for RNA-Seq experiments (condition 1, aka 'untreated') to make the\nlegend for generated plots. Order corresponds to the rpkm_isoforms_cond_1\n",
                    "sd:upstreamSource": "rnaseq_cond_1/alias",
                    "id": "#main/sample_names_cond_1"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "label": "Sample names for RNA-Seq experiments (condition 2, aka 'treated')",
                    "doc": "Aliases for RNA-Seq experiments (condition 2, aka 'treated') to make the\nlegend for generated plots. Order corresponds to the rpkm_isoforms_cond_2\n",
                    "sd:upstreamSource": "rnaseq_cond_2/alias",
                    "id": "#main/sample_names_cond_2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "Number of threads",
                    "doc": "Number of threads for those steps that support multithreading",
                    "default": 1,
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "DESeq stderr log",
                    "doc": "DESeq stderr log",
                    "outputSource": "#main/deseq/stderr_log",
                    "id": "#main/deseq_stderr_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "DESeq stdout log",
                    "doc": "DESeq stdout log",
                    "outputSource": "#main/deseq/stdout_log",
                    "id": "#main/deseq_stdout_log"
                },
                {
                    "type": "File",
                    "label": "Differentially expressed features grouped by isoforms, genes or common TSS",
                    "format": "http://edamontology.org/format_3475",
                    "doc": "DESeq generated file of differentially expressed features grouped by isoforms, genes or common TSS in TSV format",
                    "outputSource": "#main/deseq/diff_expr_file",
                    "sd:visualPlugins": [
                        {
                            "syncfusiongrid": {
                                "tab": "Differential Expression Analysis",
                                "Title": "Combined DESeq results"
                            }
                        },
                        {
                            "scatter": {
                                "tab": "Volcano Plot",
                                "Title": "Volcano",
                                "xAxisTitle": "log fold change",
                                "yAxisTitle": "-log10(pAdj)",
                                "colors": [
                                    "#b3de69"
                                ],
                                "height": 600,
                                "data": [
                                    "$9",
                                    "$13"
                                ]
                            }
                        }
                    ],
                    "id": "#main/diff_expr_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "label": "Heatmap of the 30 most highly expressed features",
                    "format": "http://edamontology.org/format_3603",
                    "doc": "Heatmap showing the expression data of the 30 most highly expressed features grouped by\nisoforms, genes or common TSS, based on the variance stabilisation transformed data\n",
                    "outputSource": "#main/deseq/gene_expr_heatmap",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Other Plots",
                                "Caption": "The 30 most highly expressed features"
                            }
                        }
                    ],
                    "id": "#main/gene_expr_heatmap"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "label": "Heatmap of the 30 most highly expressed features",
                    "format": "http://edamontology.org/format_3508",
                    "doc": "Heatmap showing the expression data of the 30 most highly expressed features grouped by\nisoforms, genes or common TSS, based on the variance stabilisation transformed data\n",
                    "outputSource": "#main/deseq/gene_expr_heatmap_pdf",
                    "id": "#main/gene_expr_heatmap_pdf"
                },
                {
                    "type": "File",
                    "label": "Phenotype data file in CLS format. Compatible with GSEA",
                    "format": "http://edamontology.org/format_2330",
                    "doc": "DESeq generated file with phenotypes in CLS format. Compatible with GSEA",
                    "outputSource": "#main/deseq/phenotypes_file",
                    "id": "#main/phenotypes_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "label": "Plot of normalised mean versus log2 fold change",
                    "format": "http://edamontology.org/format_3603",
                    "doc": "Plot of the log2 fold changes attributable to a given variable\nover the mean of normalized counts for all the samples\n",
                    "outputSource": "#main/deseq/plot_lfc_vs_mean",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Other Plots",
                                "Caption": "LFC vs mean"
                            }
                        }
                    ],
                    "id": "#main/plot_lfc_vs_mean"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "label": "Plot of normalised mean versus log2 fold change",
                    "format": "http://edamontology.org/format_3508",
                    "doc": "Plot of the log2 fold changes attributable to a given variable\nover the mean of normalized counts for all the samples\n",
                    "outputSource": "#main/deseq/plot_lfc_vs_mean_pdf",
                    "id": "#main/plot_lfc_vs_mean_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "label": "PCA plot for variance stabilized count data",
                    "format": "http://edamontology.org/format_3603",
                    "doc": "PCA plot for variance stabilized count data. Values are now approximately\nhomoskedastic (have constant variance along the range of mean values)\n",
                    "outputSource": "#main/deseq/plot_pca",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Other Plots",
                                "Caption": "PCA plot for variance stabilized count data"
                            }
                        }
                    ],
                    "id": "#main/plot_pca"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "label": "PCA plot for variance stabilized count data",
                    "format": "http://edamontology.org/format_3508",
                    "doc": "PCA plot for variance stabilized count data. Values are now approximately\nhomoskedastic (have constant variance along the range of mean values)\n",
                    "outputSource": "#main/deseq/plot_pca_pdf",
                    "id": "#main/plot_pca_pdf"
                },
                {
                    "type": "File",
                    "label": "Normalized read counts in GCT format. Compatible with GSEA",
                    "format": "http://edamontology.org/format_3709",
                    "doc": "DESeq generated file of with normalized read counts in GCT format. Compatible with GSEA",
                    "outputSource": "#main/deseq/read_counts_file",
                    "id": "#main/read_counts_file"
                }
            ],
            "steps": [
                {
                    "run": "#deseq-advanced.cwl",
                    "in": [
                        {
                            "source": "#main/rpkm_cutoff",
                            "id": "#main/deseq/rpkm_cutoff"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/deseq/threads"
                        },
                        {
                            "source": [
                                "#main/group_by",
                                "#main/rpkm_isoforms_cond_2",
                                "#main/group_isoforms_cond_2/genes_file",
                                "#main/group_isoforms_cond_2/common_tss_file"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"isoforms\") {\n      return self[1];\n    } else if (self[0] == \"genes\") {\n      return self[2];\n    } else {\n      return self[3];\n    }\n}\n",
                            "id": "#main/deseq/treated_files"
                        },
                        {
                            "source": "#main/alias_cond_2",
                            "id": "#main/deseq/treated_name"
                        },
                        {
                            "source": "#main/sample_names_cond_2",
                            "id": "#main/deseq/treated_sample_names"
                        },
                        {
                            "source": [
                                "#main/group_by",
                                "#main/rpkm_isoforms_cond_1",
                                "#main/group_isoforms_cond_1/genes_file",
                                "#main/group_isoforms_cond_1/common_tss_file"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"isoforms\") {\n      return self[1];\n    } else if (self[0] == \"genes\") {\n      return self[2];\n    } else {\n      return self[3];\n    }\n}\n",
                            "id": "#main/deseq/untreated_files"
                        },
                        {
                            "source": "#main/alias_cond_1",
                            "id": "#main/deseq/untreated_name"
                        },
                        {
                            "source": "#main/sample_names_cond_1",
                            "id": "#main/deseq/untreated_sample_names"
                        }
                    ],
                    "out": [
                        "#main/deseq/diff_expr_file",
                        "#main/deseq/plot_lfc_vs_mean",
                        "#main/deseq/gene_expr_heatmap",
                        "#main/deseq/plot_pca",
                        "#main/deseq/plot_lfc_vs_mean_pdf",
                        "#main/deseq/gene_expr_heatmap_pdf",
                        "#main/deseq/plot_pca_pdf",
                        "#main/deseq/read_counts_file",
                        "#main/deseq/phenotypes_file",
                        "#main/deseq/stdout_log",
                        "#main/deseq/stderr_log"
                    ],
                    "id": "#main/deseq"
                },
                {
                    "run": "#group-isoforms-batch.cwl",
                    "in": [
                        {
                            "source": "#main/rpkm_isoforms_cond_1",
                            "id": "#main/group_isoforms_cond_1/isoforms_file"
                        }
                    ],
                    "out": [
                        "#main/group_isoforms_cond_1/genes_file",
                        "#main/group_isoforms_cond_1/common_tss_file"
                    ],
                    "id": "#main/group_isoforms_cond_1"
                },
                {
                    "run": "#group-isoforms-batch.cwl",
                    "in": [
                        {
                            "source": "#main/rpkm_isoforms_cond_2",
                            "id": "#main/group_isoforms_cond_2/isoforms_file"
                        }
                    ],
                    "out": [
                        "#main/group_isoforms_cond_2/genes_file",
                        "#main/group_isoforms_cond_2/common_tss_file"
                    ],
                    "id": "#main/group_isoforms_cond_2"
                }
            ],
            "label": "DESeq - differential gene expression analysis",
            "doc": "Differential gene expression analysis\n=====================================\n\nDifferential gene expression analysis based on the negative binomial distribution\n\nEstimate variance-mean dependence in count data from high-throughput sequencing assays and test for differential expression based on a model using the negative binomial distribution.\n\nDESeq1\n------\n\nHigh-throughput sequencing assays such as RNA-Seq, ChIP-Seq or barcode counting provide quantitative readouts\nin the form of count data. To infer differential signal in such data correctly and with good statistical power,\nestimation of data variability throughout the dynamic range and a suitable error model are required.\nSimon Anders and Wolfgang Huber propose a method based on the negative binomial distribution, with variance and mean\nlinked by local regression and present an implementation, [DESeq](http://bioconductor.org/packages/release/bioc/html/DESeq.html),\nas an R/Bioconductor package\n\nDESeq2\n------\n\nIn comparative high-throughput sequencing assays, a fundamental task is the analysis of count data,\nsuch as read counts per gene in RNA-seq, for evidence of systematic changes across experimental conditions.\nSmall replicate numbers, discreteness, large dynamic range and the presence of outliers require a\nsuitable statistical approach. [DESeq2](http://www.bioconductor.org/packages/release/bioc/html/DESeq2.html),\na method for differential analysis of count data,\nusing shrinkage estimation for dispersions and fold changes to improve stability and interpretability of estimates.\nThis enables a more quantitative analysis focused on the strength rather than the mere presence of differential expression.",
            "id": "#main",
            "http://schema.org/name": "DESeq - differential gene expression analysis",
            "http://schema.org/alternateName": "Differential gene expression analysis based on the negative binomial distribution",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/deseq.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Datirium, LLC",
                    "http://schema.org/member": [
                        {
                            "class": "http://schema.org/Person",
                            "http://schema.org/name": "Artem BArski",
                            "http://schema.org/email": "mailto:Artem.Barski@datirum.com"
                        },
                        {
                            "class": "http://schema.org/Person",
                            "http://schema.org/name": "Andrey Kartashov",
                            "http://schema.org/email": "mailto:Andrey.Kartashov@datirium.com",
                            "http://schema.org/sameAs": [
                                {
                                    "id": "#0000-0001-9102-5681"
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
